@@ -109,7 +109,7 @@ class Exceptions:
 
 class OpenSearchServiceClient(BaseClient):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html)
     """
 
@@ -128,7 +128,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to accept an inbound cross-cluster connection
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.accept_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#accept_inbound_connection)
         """
 
@@ -136,7 +136,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Attaches tags to an existing domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.add_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#add_tags)
         """
 
@@ -146,7 +146,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Associates a package with an Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.associate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.associate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#associate_package)
         """
 
@@ -154,7 +154,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Check if an operation can be paginated.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.can_paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.can_paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#can_paginate)
         """
 
@@ -165,7 +165,7 @@ class OpenSearchServiceClient(BaseClient):
         Cancels a scheduled service software update for an Amazon OpenSearch Service
         domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.cancel_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.cancel_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#cancel_service_software_update)
         """
 
@@ -192,7 +192,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Creates a new Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.create_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_domain)
         """
 
@@ -207,7 +207,7 @@ class OpenSearchServiceClient(BaseClient):
         Creates a new cross-cluster connection from a local OpenSearch domain to a
         remote OpenSearch domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.create_outbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_outbound_connection)
         """
 
@@ -222,7 +222,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Create a package for use with Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.create_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.create_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#create_package)
         """
 
@@ -230,7 +230,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Permanently deletes the specified domain and all of its data.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.delete_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_domain)
         """
 
@@ -241,7 +241,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to delete an existing inbound cross-cluster
         connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.delete_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_inbound_connection)
         """
 
@@ -252,7 +252,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the local domain owner to delete an existing outbound cross-cluster
         connection.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.delete_outbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_outbound_connection)
         """
 
@@ -260,7 +260,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Deletes the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.delete_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#delete_package)
         """
 
@@ -269,7 +269,7 @@ class OpenSearchServiceClient(BaseClient):
         Returns domain configuration information about the specified domain, including
         the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain)
         """
 
@@ -280,7 +280,7 @@ class OpenSearchServiceClient(BaseClient):
         Provides scheduled Auto-Tune action details for the domain, such as Auto-Tune
         action type, description, severity, and scheduled date.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_auto_tunes)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain_auto_tunes)
         """
 
@@ -289,7 +289,7 @@ class OpenSearchServiceClient(BaseClient):
         Provides cluster configuration information about the specified domain, such as
         the state, creation date, update version, and update date for cluster options.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domain_config)
         """
 
@@ -298,7 +298,7 @@ class OpenSearchServiceClient(BaseClient):
         Returns domain configuration information about the specified domains, including
         the domain ID, domain endpoint, and domain ARN.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_domains)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_domains)
         """
 
@@ -312,7 +312,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists all the inbound cross-cluster connections for a remote domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_inbound_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_inbound_connections)
         """
 
@@ -327,7 +327,7 @@ class OpenSearchServiceClient(BaseClient):
         Describe the limits for a given instance type and OpenSearch or Elasticsearch
         version.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_instance_type_limits)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_instance_type_limits)
         """
 
@@ -341,7 +341,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists all the outbound cross-cluster connections for a local domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_outbound_connections)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_outbound_connections)
         """
 
@@ -355,7 +355,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Describes all packages available to Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_packages)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_packages)
         """
 
@@ -365,7 +365,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists available reserved OpenSearch instance offerings.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instance_offerings)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_reserved_instance_offerings)
         """
 
@@ -375,7 +375,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns information about reserved OpenSearch instances for this account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.describe_reserved_instances)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#describe_reserved_instances)
         """
 
@@ -385,7 +385,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Dissociates a package from the Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.dissociate_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#dissociate_package)
         """
 
@@ -399,7 +399,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Generate a presigned url given a client, its method, and arguments.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.generate_presigned_url)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.generate_presigned_url)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#generate_presigned_url)
         """
 
@@ -409,7 +409,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns a list of upgrade-compatible versions of OpenSearch/Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.get_compatible_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_compatible_versions)
         """
 
@@ -420,7 +420,7 @@ class OpenSearchServiceClient(BaseClient):
         Returns a list of package versions, along with their creation time and commit
         message.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.get_package_version_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_package_version_history)
         """
 
@@ -430,7 +430,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Retrieves the complete history of the last 10 upgrades performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_history)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_upgrade_history)
         """
 
@@ -439,7 +439,7 @@ class OpenSearchServiceClient(BaseClient):
         Retrieves the latest status of the last upgrade or upgrade eligibility check
         performed on the domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.get_upgrade_status)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#get_upgrade_status)
         """
 
@@ -449,7 +449,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns the names of all domains owned by the current user's account.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.list_domain_names)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_domain_names)
         """
 
@@ -459,7 +459,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists all Amazon OpenSearch Service domains associated with the package.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.list_domains_for_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_domains_for_package)
         """
 
@@ -477,7 +477,7 @@ class OpenSearchServiceClient(BaseClient):
         client.list_instance_type_details( EngineVersion='string', DomainName='string',
         MaxResults=123, NextToken='stri...
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.list_instance_type_details)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_instance_type_details)
         """
 
@@ -487,7 +487,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Lists all packages associated with the Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.list_packages_for_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_packages_for_domain)
         """
 
@@ -495,7 +495,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Returns all tags for the given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.list_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_tags)
         """
 
@@ -505,7 +505,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         List all supported versions of OpenSearch and Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.list_versions)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#list_versions)
         """
 
@@ -515,7 +515,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Allows you to purchase reserved OpenSearch instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.purchase_reserved_instance_offering)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#purchase_reserved_instance_offering)
         """
 
@@ -526,7 +526,7 @@ class OpenSearchServiceClient(BaseClient):
         Allows the remote domain owner to reject an inbound cross-cluster connection
         request.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.reject_inbound_connection)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#reject_inbound_connection)
         """
 
@@ -534,7 +534,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Removes the specified set of tags from the given domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.remove_tags)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#remove_tags)
         """
 
@@ -544,7 +544,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Schedules a service software update for an Amazon OpenSearch Service domain.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.start_service_software_update)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.start_service_software_update)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#start_service_software_update)
         """
 
@@ -564,13 +564,14 @@ class OpenSearchServiceClient(BaseClient):
         DomainEndpointOptions: "DomainEndpointOptionsTypeDef" = ...,
         NodeToNodeEncryptionOptions: "NodeToNodeEncryptionOptionsTypeDef" = ...,
         AdvancedSecurityOptions: "AdvancedSecurityOptionsInputTypeDef" = ...,
-        AutoTuneOptions: "AutoTuneOptionsTypeDef" = ...
+        AutoTuneOptions: "AutoTuneOptionsTypeDef" = ...,
+        DryRun: bool = ...
     ) -> UpdateDomainConfigResponseTypeDef:
         """
         Modifies the cluster configuration of the specified domain, such as setting the
         instance type and the number of instances.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.update_domain_config)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#update_domain_config)
         """
 
@@ -585,7 +586,7 @@ class OpenSearchServiceClient(BaseClient):
         """
         Updates a package for use with Amazon OpenSearch Service domains.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.update_package)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.update_package)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#update_package)
         """
 
@@ -601,6 +602,6 @@ class OpenSearchServiceClient(BaseClient):
         Allows you to either upgrade your domain or perform an upgrade eligibility check
         to a compatible version of OpenSearch or Elasticsearch.
 
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.1/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.20.12/reference/services/opensearch.html#OpenSearchService.Client.upgrade_domain)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_opensearch/client.html#upgrade_domain)
         """
