@@ -122,6 +122,7 @@ __all__ = (
     "DomainInformationContainerTypeDef",
     "DomainPackageDetailsTypeDef",
     "DomainStatusTypeDef",
+    "DryRunResultsTypeDef",
     "DurationTypeDef",
     "EBSOptionsStatusTypeDef",
     "EBSOptionsTypeDef",
@@ -978,6 +979,15 @@ class DomainStatusTypeDef(_RequiredDomainStatusTypeDef, _OptionalDomainStatusTyp
     pass
 
 
+DryRunResultsTypeDef = TypedDict(
+    "DryRunResultsTypeDef",
+    {
+        "DeploymentType": str,
+        "Message": str,
+    },
+    total=False,
+)
+
 DurationTypeDef = TypedDict(
     "DurationTypeDef",
     {
@@ -1718,6 +1728,7 @@ _OptionalUpdateDomainConfigRequestRequestTypeDef = TypedDict(
         "NodeToNodeEncryptionOptions": "NodeToNodeEncryptionOptionsTypeDef",
         "AdvancedSecurityOptions": "AdvancedSecurityOptionsInputTypeDef",
         "AutoTuneOptions": "AutoTuneOptionsTypeDef",
+        "DryRun": bool,
     },
     total=False,
 )
@@ -1734,6 +1745,7 @@ UpdateDomainConfigResponseTypeDef = TypedDict(
     "UpdateDomainConfigResponseTypeDef",
     {
         "DomainConfig": "DomainConfigTypeDef",
+        "DryRunResults": "DryRunResultsTypeDef",
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
